@@ -282,7 +282,7 @@ void ConfigurationDialog::recent_items_max_changed(GtkSpinButton* button)
 
 void ConfigurationDialog::toggle_remember_favorites(GtkToggleButton* button)
 {
-	wm_settings->favorites_in_recent = !gtk_toggle_button_get_active(button);
+	wm_settings->favorites_in_recent = gtk_toggle_button_get_active(button);
 	wm_settings->set_modified();
 }
 
@@ -662,6 +662,11 @@ GtkWidget* ConfigurationDialog::init_appearance_tab()
 	gtk_range_set_value(GTK_RANGE(m_background_opacity), wm_settings->menu_opacity);
 	g_signal_connect_slot(m_background_opacity, "value-changed", &ConfigurationDialog::background_opacity_changed, this);
 
+	GdkScreen* screen = gtk_widget_get_screen(m_window);
+	const bool enabled = gdk_screen_is_composited(screen);
+	gtk_widget_set_sensitive(label, enabled);
+	gtk_widget_set_sensitive(GTK_WIDGET(m_background_opacity), enabled);
+
 	return GTK_WIDGET(page);
 }
 
@@ -727,9 +732,9 @@ GtkWidget* ConfigurationDialog::init_behavior_tab()
 	g_signal_connect_slot(m_recent_items_max, "value-changed", &ConfigurationDialog::recent_items_max_changed, this);
 
 	// Add option to remember favorites
-	m_remember_favorites = gtk_check_button_new_with_mnemonic(_("Ignore _favorites"));
+	m_remember_favorites = gtk_check_button_new_with_mnemonic(_("Include _favorites"));
 	gtk_grid_attach(recent_table, m_remember_favorites, 0, 1, 2, 1);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_remember_favorites), !wm_settings->favorites_in_recent);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_remember_favorites), wm_settings->favorites_in_recent);
 	g_signal_connect_slot(m_remember_favorites, "toggled", &ConfigurationDialog::toggle_remember_favorites, this);
 
 	// Add option to display recently used
