@@ -89,6 +89,7 @@ WhiskerMenu::Window::Window(Plugin* plugin) :
 	g_signal_connect_slot(m_window, "enter-notify-event", &Window::on_enter_notify_event, this);
 	g_signal_connect_slot(m_window, "leave-notify-event", &Window::on_leave_notify_event, this);
 	g_signal_connect_slot(m_window, "button-press-event", &Window::on_button_press_event, this);
+	g_signal_connect_slot(m_window, "button-release-event", &Window::on_button_release_event, this);
 	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event, this);
 	g_signal_connect_slot(m_window, "key-press-event", &Window::on_key_press_event_after, this, true);
 	g_signal_connect_slot(m_window, "map-event", &Window::on_map_event, this);
@@ -283,6 +284,9 @@ void WhiskerMenu::Window::hide()
 {
 	ungrab_pointer();
 
+	// Reset any pressed category buttons
+	unset_pressed_category();
+
 	// Hide command buttons to remove active border
 	for (int i = 0; i < 4; ++i)
 	{
@@ -472,7 +476,7 @@ void WhiskerMenu::Window::show(const Position position)
 		g_object_ref(m_commands_box);
 		if (m_layout_commands_alternate)
 		{
-			if (!wm_settings->position_categories_alternate)
+			if (!m_sidebar_size_group)
 			{
 				m_sidebar_size_group = gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL);
 				gtk_size_group_add_widget(m_sidebar_size_group, GTK_WIDGET(m_sidebar));
@@ -484,25 +488,44 @@ void WhiskerMenu::Window::show(const Position position)
 		}
 		else
 		{
-			g_object_unref(m_sidebar_size_group);
-			m_sidebar_size_group = NULL;
+			if (m_sidebar_size_group)
+			{
+				gtk_size_group_remove_widget(m_sidebar_size_group, GTK_WIDGET(m_sidebar));
+				gtk_size_group_remove_widget(m_sidebar_size_group, GTK_WIDGET(m_commands_box));
+				g_object_unref(m_sidebar_size_group);
+				m_sidebar_size_group = NULL;
+			}
 
 			gtk_container_remove(GTK_CONTAINER(m_search_box), GTK_WIDGET(m_commands_box));
 			gtk_box_pack_start(m_title_box, GTK_WIDGET(m_commands_box), false, false, 0);
 		}
 		g_object_unref(m_commands_box);
 	}
+
 	if ((layout_left && !wm_settings->position_categories_alternate)
 			|| (!layout_left && wm_settings->position_categories_alternate))
 	{
 		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_stack), 0);
 		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 1);
+
+		if (m_layout_commands_alternate)
+		{
+			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 0);
+			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_box), 1);
+		}
 	}
 	else
 	{
 		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_panels_stack), 1);
 		gtk_box_reorder_child(m_contents_box, GTK_WIDGET(m_sidebar), 0);
+
+		if (m_layout_commands_alternate)
+		{
+			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 1);
+			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_box), 0);
+		}
 	}
+
 	if (layout_left != m_layout_left)
 	{
 		m_layout_left = layout_left;
@@ -519,9 +542,6 @@ void WhiskerMenu::Window::show(const Position position)
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_profilepic->get_widget()), 0);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_username), 1);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_resizer->get_widget()), 2);
-
-			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 0);
-			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_box), 1);
 		}
 		else if (m_layout_commands_alternate)
 		{
@@ -536,9 +556,6 @@ void WhiskerMenu::Window::show(const Position position)
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_profilepic->get_widget()), 2);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_username), 1);
 			gtk_box_reorder_child(m_title_box, GTK_WIDGET(m_resizer->get_widget()), 0);
-
-			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_search_entry), 1);
-			gtk_box_reorder_child(m_search_box, GTK_WIDGET(m_commands_box), 0);
 		}
 		else if (m_layout_left)
 		{
@@ -747,6 +764,14 @@ gboolean WhiskerMenu::Window::on_button_press_event(GtkWidget*, GdkEvent* event)
 
 //-----------------------------------------------------------------------------
 
+gboolean WhiskerMenu::Window::on_button_release_event(GtkWidget*, GdkEvent*)
+{
+	unset_pressed_category();
+	return false;
+}
+
+//-----------------------------------------------------------------------------
+
 gboolean WhiskerMenu::Window::on_key_press_event(GtkWidget* widget, GdkEvent* event)
 {
 	GdkEventKey* key_event = reinterpret_cast<GdkEventKey*>(event);
@@ -1001,3 +1026,12 @@ void WhiskerMenu::Window::search()
 }
 
 //-----------------------------------------------------------------------------
+
+void WhiskerMenu::Window::unset_pressed_category()
+{
+	// Force a state change on sidebar buttons
+	gtk_widget_set_sensitive(GTK_WIDGET(m_sidebar_buttons), false);
+	gtk_widget_set_sensitive(GTK_WIDGET(m_sidebar_buttons), true);
+}
+
+//-----------------------------------------------------------------------------
